==> ksqlplus-0.9.3.tar.gz: ksqlplus-0.9.3/ksqlplus/resource.h <==
/***************************************************************************
    resource.h  -  Application constants

    begin                : Fri Dec 10 16:02:01 MSK 1999
    copyright            : (C) 1999 by Yury Lebedev
    email                : yurylebedev@mail.ru
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef RESOURCE_H
#define RESOURCE_H

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

///////////////////////////////////////////////////////////////////
// resource.h  -- contains macros used for commands


///////////////////////////////////////////////////////////////////
// COMMAND VALUES FOR MENUBAR AND TOOLBAR ENTRIES


///////////////////////////////////////////////////////////////////
// File-menu entries
#define ID_FILE_NEW_WINDOW          10010
#define ID_FILE_NEW                 10020
#define ID_FILE_OPEN                10030
#define ID_FILE_OPEN_RECENT         10040
#define ID_FILE_CLOSE               10050

#define ID_FILE_SAVE                10060
#define ID_FILE_SAVE_AS             10070
#define ID_FILE_SAVE_OUTPUT         10071

#define ID_FILE_PRINT               10080
#define ID_FILE_PRINT_OUTPUT        10081

#define ID_FILE_QUIT                10090

#define ID_FILE_LOGIN               10100

///////////////////////////////////////////////////////////////////
// Edit-menu entries
#define ID_EDIT_COPY                11010
#define ID_EDIT_CUT                 11020
#define ID_EDIT_PASTE               11030
#define ID_EDIT_CLEAR               11040

#define ID_EDIT_COPY_OUTPUT         11050
#define ID_EDIT_CLEAR_OUTPUT        11060
#define ID_EDIT_SELECT_ALL_OUTPUT   11070

#define ID_EDIT_KEYS                11080

///////////////////////////////////////////////////////////////////
// View-menu entries                    
#define ID_VIEW_TOOLBAR             12010
#define ID_VIEW_STATUSBAR           12020

#define ID_VIEW_FONT                12030

///////////////////////////////////////////////////////////////////
// Command-menu entries
#define ID_COMMAND_EXECUTE          13010
#define ID_COMMAND_BREAK            13020
#define ID_COMMAND_PREV             13030
#define ID_COMMAND_NEXT             13040
#define ID_COMMAND_HISTORY          13050

///////////////////////////////////////////////////////////////////
// Help-menu entries
#define ID_HELP_CONTENTS            1001

///////////////////////////////////////////////////////////////////
// Application-specific key actions
#define KEY_COMMAND_EXECUTE         "Execute"
#define KEY_COMMAND_PREV            "Previous"
#define KEY_COMMAND_NEXT            "Next"

///////////////////////////////////////////////////////////////////
// General application values
#define ID_STATUS_MSG               1002
#define ID_STATUS_ROW_COL           1003

#define MAX_COMMAND_HISTORY         96
#define MAX_RECENT_FILES            10
#define MAX_TOOLBARS                2

#endif // RESOURCE_H

==> ksqlplus-0.9.4.tar.gz: ksqlplus-0.9.4/ksqlplus/resource.h <==
/***************************************************************************
    resource.h  -  Application's constants

    begin                : Fri Dec 10 16:02:01 MSK 1999
    copyright            : (C) 1999 by Yury Lebedev
    email                : yurylebedev@mail.ru
    home page            : http://devel-home.kde.org/~ksqlplus
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef RESOURCE_H
#define RESOURCE_H

// COMMAND VALUES FOR MENUBAR AND TOOLBAR ENTRIES

// File-menu entries
#define ID_FILE_NEW_WINDOW          10010
#define ID_FILE_NEW                 10020
#define ID_FILE_OPEN                10030
#define ID_FILE_OPEN_RECENT         10040
#define ID_FILE_CLOSE               10050

#define ID_FILE_SAVE                10060
#define ID_FILE_SAVE_AS             10070
#define ID_FILE_SAVE_OUTPUT         10071

#define ID_FILE_PRINT               10080
#define ID_FILE_PRINT_OUTPUT        10081

#define ID_FILE_QUIT                10090

#define ID_FILE_LOGIN               10100

// Edit-menu entries
#define ID_EDIT_COPY                11010
#define ID_EDIT_CUT                 11020
#define ID_EDIT_PASTE               11030
#define ID_EDIT_CLEAR               11040

#define ID_EDIT_COPY_OUTPUT         11050
#define ID_EDIT_CLEAR_OUTPUT        11060
#define ID_EDIT_SELECT_ALL_OUTPUT   11070

#define ID_EDIT_KEYS                11080
#define ID_EDIT_SQLPLUS             11090

// View-menu entries
#define ID_VIEW_TOOLBAR             12010
#define ID_VIEW_STATUSBAR           12020

#define ID_VIEW_FONT                12030

// Command-menu entries
#define ID_COMMAND_EXECUTE          13010
#define ID_COMMAND_BREAK            13020
#define ID_COMMAND_PREV             13030
#define ID_COMMAND_NEXT             13040
#define ID_COMMAND_HISTORY          13050

// Help-menu entries
#define ID_HELP_CONTENTS            1001


// Application-specific key actions
#define KEY_COMMAND_EXECUTE         "Execute"
#define KEY_COMMAND_PREV            "Previous"
#define KEY_COMMAND_NEXT            "Next"


// General application values
#define ID_STATUS_MSG               1002
#define ID_STATUS_MODIFIED          1003
#define ID_STATUS_OVERWRITE         1004
#define ID_STATUS_ROW_COL           1005

#define MAX_COMMAND_HISTORY         96
#define MAX_RECENT_FILES            10
#define MAX_TOOLBARS                2

#endif // RESOURCE_H
